##  Overview
Admin users of a workspace with the Meta Model v3 can configure their Meta Model to align their workspace with Meta Model v4. Broadly, you do the following changes to align with Meta Model v4:
  * [Rename existing Fact Sheet type names](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__rename_three_existing_fact_sheet_types): Rename User Group, Project, and Process Fact Sheet types to Organization, Initiative, and Business Context, respectively.
  * [Introduce new Fact Sheet type](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__introduce_new_fact_sheet_type_-_platform): Create a new Fact Sheet type named Platform and define its relationships with other Fact Sheet types.
  * [Add Fact Sheet subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types): Add new Fact Sheet subtypes to Organization, Initiative, Business Context, Application, and Interface and additional subtypes to IT Component.
  * [Introduce new subsections and fields](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__introduce_new_subsections_and_fields_to_business_capability): Add a new subsection and the necessary fields to the Business Capability Fact Sheet to capture the business capabilities' current and target maturity levels.
  * [Standardize Fact Sheet color and order](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__standardize_fact_sheet_colors_and_order): Align the colors following SAP LeanIX standards and arrange Fact Sheets in the recommended order. This standardization helps all workspace users follow SAP LeanIX standard documentation and instructions effectively.


In the following sections, detailed instructions for implementing the aforementioned changes will be provided. To have an overview of key changes from Meta Model v3, see [Delta to Meta Model v3](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD).
